@@ -50,7 +50,7 @@ public class MediaDatabase {
 
     private SQLiteDatabase mDb;
     private static final String DB_NAME = "vlc_database";
-    private static final int DB_VERSION = 18;
+    private static final int DB_VERSION = 19;
     private static final int CHUNK_SIZE = 50;
 
     private static final String DIR_TABLE_NAME = "directories_table";
@@ -161,10 +161,15 @@ public class MediaDatabase {
         }
 
         public void dropMediaTableQuery(SQLiteDatabase db) {
-            String query = "DROP TABLE " + MEDIA_TABLE_NAME + ";";
-            db.execSQL(query);
-            query = "DROP TABLE " + MEDIA_VIRTUAL_TABLE_NAME + ";";
-            db.execSQL(query);
+            try {
+                String query = "DROP TABLE " + MEDIA_TABLE_NAME + ";";
+                db.execSQL(query);
+                query = "DROP TABLE " + MEDIA_VIRTUAL_TABLE_NAME + ";";
+                db.execSQL(query);
+            } catch(SQLiteException e)
+            {
+                Log.w(TAG, "SQLite tables could not be dropped! Maybe they were missing...");
+            }
         }
 
         public void createMediaTableQuery(SQLiteDatabase db) {
@@ -190,7 +195,7 @@ public class MediaDatabase {
                     + ");";
             db.execSQL(query);
             db.execSQL("PRAGMA recursive_triggers='ON'"); //Needed for delete trigger
-            query = "CREATE VIRTUAL TABLE IF NOT EXISTS "
+            query = "CREATE VIRTUAL TABLE "
                     + MEDIA_VIRTUAL_TABLE_NAME + " USING FTS3 ("
                     + MEDIA_LOCATION + ", "
                     + MEDIA_TITLE + ", "
@@ -247,8 +252,13 @@ public class MediaDatabase {
         }
 
         public void dropMRLTableQuery(SQLiteDatabase db) {
-            String query = "DROP TABLE " + MRL_TABLE_NAME + ";";
-            db.execSQL(query);
+            try {
+                String query = "DROP TABLE " + MRL_TABLE_NAME + ";";
+                db.execSQL(query);
+            } catch(SQLiteException e)
+            {
+                Log.w(TAG, "SQLite tables could not be dropped! Maybe they were missing...");
+            }
         }
 
         private void createNetworkFavTableQuery(SQLiteDatabase db) {
@@ -261,8 +271,12 @@ public class MediaDatabase {
         }
 
         public void dropNetworkFavTableQuery(SQLiteDatabase db) {
-            String query = "DROP TABLE " + NETWORK_FAV_TABLE_NAME + ";";
-            db.execSQL(query);
+            try {
+                String query = "DROP TABLE " + NETWORK_FAV_TABLE_NAME + ";";
+                db.execSQL(query);
+            } catch(SQLiteException e) {
+                Log.w(TAG, "SQLite tables could not be dropped! Maybe they were missing...");
+            }
         }
 
         @Override
