@@ -29,6 +29,7 @@ import android.content.IntentFilter;
 import android.content.SharedPreferences;
 import android.content.SharedPreferences.Editor;
 import android.database.Cursor;
+import android.net.Uri;
 import android.os.Build;
 import android.os.Bundle;
 import android.os.Handler;
@@ -57,6 +58,7 @@ import android.view.WindowManager;
 import android.view.inputmethod.InputMethodManager;
 import android.widget.AdapterView;
 import android.widget.AdapterView.OnItemClickListener;
+import android.widget.FilterQueryProvider;
 import android.widget.ListView;
 import android.widget.ProgressBar;
 import android.widget.TextView;
@@ -72,12 +74,14 @@ import org.videolan.vlc.audio.AudioService;
 import org.videolan.vlc.audio.AudioServiceController;
 import org.videolan.vlc.gui.SidebarAdapter.SidebarEntry;
 import org.videolan.vlc.gui.audio.AudioAlbumsSongsFragment;
+import org.videolan.vlc.gui.audio.AudioBrowserFragment;
 import org.videolan.vlc.gui.audio.AudioPlayer;
 import org.videolan.vlc.gui.audio.EqualizerFragment;
 import org.videolan.vlc.gui.network.NetworkFragment;
 import org.videolan.vlc.gui.video.MediaInfoFragment;
 import org.videolan.vlc.gui.video.VideoGridFragment;
 import org.videolan.vlc.gui.video.VideoListAdapter;
+import org.videolan.vlc.gui.video.VideoPlayerActivity;
 import org.videolan.vlc.interfaces.IRefreshable;
 import org.videolan.vlc.interfaces.ISortable;
 import org.videolan.vlc.util.AndroidDevices;
@@ -91,7 +95,7 @@ import java.util.Arrays;
 import java.util.HashMap;
 import java.util.List;
 
-public class MainActivity extends ActionBarActivity implements OnItemClickListener, SearchView.OnQueryTextListener, SearchSuggestionsAdapter.SuggestionDisplay {
+public class MainActivity extends ActionBarActivity implements OnItemClickListener, SearchSuggestionsAdapter.SuggestionDisplay, FilterQueryProvider {
     public final static String TAG = "VLC/MainActivity";
 
     protected static final String ACTION_SHOW_PROGRESSBAR = "org.videolan.vlc.gui.ShowProgressBar";
@@ -120,11 +124,6 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
     private TextView mInfoText;
     private View mAudioPlayerFilling;
     private String mCurrentFragment;
-    private String mPreviousFragment;
-    private List<String> secondaryFragments = Arrays.asList("albumsSongs", "equalizer",
-                                                            "about", "search", "mediaInfo",
-                                                            "videoGroupList");
-    private HashMap<String, Fragment> mSecondaryFragments = new HashMap<String, Fragment>();
 
     private SharedPreferences mSettings;
 
@@ -274,8 +273,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
     }
 
     private void applyTheme() {
-        SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(this);
-        boolean enableBlackTheme = pref.getBoolean("enable_black_theme", false);
+        boolean enableBlackTheme = mSettings.getBoolean("enable_black_theme", false);
         if (enableBlackTheme) {
             setTheme(R.style.Theme_VLC_Black);
         }
@@ -340,7 +338,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
          */
         if(current == null || (!current.getTag().equals(mCurrentFragment) && found)) {
             Log.d(TAG, "Reloading displayed fragment");
-            if(mCurrentFragment == null || secondaryFragments.contains(mCurrentFragment))
+            if(mCurrentFragment == null)
                 mCurrentFragment = "video";
             if(!SidebarAdapter.sidebarFragments.contains(mCurrentFragment)) {
                 Log.d(TAG, "Unknown fragment \"" + mCurrentFragment + "\", resetting to video");
@@ -425,12 +423,6 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                     return;
                 }
             }
-
-            // If it's the albums songs fragment, we leave it.
-            if (secondaryFragments.contains(mCurrentFragment)) {
-                popSecondaryFragment();
-                return;
-            }
         }
         finish();
     }
@@ -468,64 +460,21 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
         ft.commit();
     }
 
-    /**
-     * Fetch a secondary fragment.
-     * @param id the fragment id
-     * @return the fragment.
-     */
-    public Fragment fetchSecondaryFragment(String id) {
-        if (mSecondaryFragments.containsKey(id)
-            && mSecondaryFragments.get(id) != null)
-            return mSecondaryFragments.get(id);
-
-        Fragment f;
-        if (id.equals("albumsSongs")) {
-            f = new AudioAlbumsSongsFragment();
-        } else if(id.equals("equalizer")) {
-            f = new EqualizerFragment();
-        } else if(id.equals("about")) {
-            f = new AboutFragment();
-        } else if(id.equals("mediaInfo")) {
-            f = new MediaInfoFragment();
-        } else if(id.equals("videoGroupList")) {
-            f = new VideoGridFragment();
-        }
-        else {
-            throw new IllegalArgumentException("Wrong fragment id.");
-        }
-        f.setRetainInstance(true);
-        mSecondaryFragments.put(id, f);
-        return f;
-    }
-
     /**
      * Show a secondary fragment.
      */
-    public Fragment showSecondaryFragment(String fragmentTag) {
-        // Slide down the audio player if needed.
-        slideDownAudioPlayer();
-
-        if (mCurrentFragment != null) {
-            // Do not show the new fragment if the requested fragment is already shown.
-            if (mCurrentFragment.equals(fragmentTag))
-                return null;
-
-            if (!secondaryFragments.contains(mCurrentFragment))
-                mPreviousFragment = mCurrentFragment;
-        }
-
-        mCurrentFragment = fragmentTag;
-        Fragment frag = fetchSecondaryFragment(mCurrentFragment);
-        ShowFragment(this, mCurrentFragment, frag, mPreviousFragment);
-        return frag;
+    public void showSecondaryFragment(String fragmentTag) {
+        showSecondaryFragment(fragmentTag, null);
     }
 
-    /**
-     * Hide the current secondary fragment.
-     */
-    public void popSecondaryFragment() {
-        getSupportFragmentManager().popBackStackImmediate();
-        mCurrentFragment = mPreviousFragment;
+    public void showSecondaryFragment(String fragmentTag, String param) {
+        Intent i = new Intent(this, SecondaryActivity.class);
+        i.putExtra("fragment", fragmentTag);
+        if (param != null)
+            i.putExtra("param", param);
+        startActivity(i);
+        // Slide down the audio player if needed.
+        slideDownAudioPlayer();
     }
 
     /** Create menu from XML
@@ -546,9 +495,10 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                     (SearchManager) getSystemService(Context.SEARCH_SERVICE);
             mSearchView = (SearchView) MenuItemCompat.getActionView(menu.findItem(R.id.ml_menu_search));
             mSearchView.setSearchableInfo(searchManager.getSearchableInfo(getComponentName()));
-            mSearchView.setOnQueryTextListener(this);
             mSearchView.setQueryHint(getString(R.string.search_hint));
-            mSearchView.setSuggestionsAdapter(new SearchSuggestionsAdapter(this, null));
+            SearchSuggestionsAdapter searchSuggestionsAdapter = new SearchSuggestionsAdapter(this, null);
+            searchSuggestionsAdapter.setFilterQueryProvider(this);
+            mSearchView.setSuggestionsAdapter(searchSuggestionsAdapter);
         } else
             menu.findItem(R.id.ml_menu_search).setVisible(false);
         return super.onCreateOptionsMenu(menu);
@@ -581,7 +531,8 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
             menu.findItem(R.id.ml_menu_save).setVisible(false);
         if (current instanceof MRLPanelFragment)
             menu.findItem(R.id.ml_menu_clean).setVisible(!((MRLPanelFragment) current).isEmpty());
-        menu.findItem(R.id.ml_menu_last_playlist).setVisible(SidebarEntry.ID_AUDIO.equals(mCurrentFragment));
+        boolean showLast = current instanceof AudioBrowserFragment || (current instanceof VideoGridFragment && mSettings.getString(PreferencesActivity.VIDEO_LAST, null) != null);
+        menu.findItem(R.id.ml_menu_last_playlist).setVisible(showLast);
 
 
 
@@ -622,19 +573,19 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 break;
             // Restore last playlist
             case R.id.ml_menu_last_playlist:
-                Intent i = new Intent(AudioService.ACTION_REMOTE_LAST_PLAYLIST);
-                sendBroadcast(i);
+                if (current instanceof AudioBrowserFragment) {
+                    Intent i = new Intent(AudioService.ACTION_REMOTE_LAST_PLAYLIST);
+                    sendBroadcast(i);
+                } else if (current instanceof VideoGridFragment) {
+                    String location = Uri.decode(mSettings.getString(PreferencesActivity.VIDEO_LAST, null));
+                    if (location != null)
+                        VideoPlayerActivity.start(this, location);
+                }
                 break;
             case android.R.id.home:
                 // Slide down the audio player.
                 if (slideDownAudioPlayer())
                     break;
-
-                // If it's the albums songs view, a "backpressed" action shows .
-                if (secondaryFragments.contains(mCurrentFragment)) {
-                    popSecondaryFragment();
-                    break;
-                }
                 /* Toggle the sidebar */
                 if (mDrawerToggle.onOptionsItemSelected(item)) {
                     return true;
@@ -821,19 +772,8 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
     };
 
     @Override
-    public boolean onQueryTextSubmit(String query) {
-        return false;
-    }
-
-    @Override
-    public boolean onQueryTextChange(String newText) {
-        if (newText.length() < 3) {
-            mSearchView.getSuggestionsAdapter().swapCursor(null);
-            return false;
-        }
-        Cursor cursor = MediaDatabase.getInstance().queryMedia(newText);
-        mSearchView.getSuggestionsAdapter().swapCursor(cursor);
-        return true;
+    public Cursor runQuery(CharSequence constraint) {
+        return MediaDatabase.getInstance().queryMedia(constraint.toString());
     }
 
     private static class MainActivityHandler extends WeakHandler<MainActivity> {
@@ -995,7 +935,7 @@ public class MainActivity extends ActionBarActivity implements OnItemClickListen
                 @Override
                 public void onClick(View v) {
                     removeTipViewIfDisplayed();
-                    Editor editor = PreferenceManager.getDefaultSharedPreferences(MainActivity.this).edit();
+                    Editor editor = mSettings.edit();
                     editor.putBoolean(settingKey, true);
                     Util.commitPreferences(editor);
                 }
