@@ -60,6 +60,7 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
 
     public static final String SMB_ROOT = "smb";
     public static final String KEY_MRL = "key_mrl";
+    public static final String KEY_MEDIA = "key_media";
     public static final String KEY_POSITION = "key_list";
 
     private NetworkFragmentHandler mHandler;
@@ -70,7 +71,8 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
     private LinearLayoutManager mLayoutManager;
     TextView mEmptyView;
     public String mMrl;
-    private int savedPosition = -1, mFavorites = 0;
+    private MediaWrapper mCurrentMedia;
+    private int mSavedPosition = -1, mFavorites = 0;
     private boolean mRoot;
     LibVLC mLibVLC = LibVLC.getExistingInstance();
 
@@ -79,8 +81,12 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
         if (bundle == null)
             bundle = getArguments();
         if (bundle != null){
-            mMrl = bundle.getString(KEY_MRL);
-            savedPosition = bundle.getInt(KEY_POSITION);
+            mCurrentMedia = bundle.getParcelable(KEY_MEDIA);
+            if (mCurrentMedia != null)
+                mMrl = mCurrentMedia.getLocation();
+            else
+                mMrl = bundle.getString(KEY_MRL);
+            mSavedPosition = bundle.getInt(KEY_POSITION);
         }
         if (mMrl == null)
             mMrl = SMB_ROOT;
@@ -100,7 +106,7 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
         mRecyclerView.setOnScrollListener(mScrollListener);
 
         mSwipeRefreshLayout = (SwipeRefreshLayout) v.findViewById(R.id.swipeLayout);
-        mSwipeRefreshLayout.setColorSchemeResources(R.color.darkerorange);
+        mSwipeRefreshLayout.setColorSchemeResources(R.color.orange700);
         mSwipeRefreshLayout.setOnRefreshListener(this);
         return v;
     }
@@ -109,8 +115,8 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
         super.onStop();
         if (mMediaBrowser != null)
             mMediaBrowser.release();
-        savedPosition = mRecyclerView.getScrollY();
     }
+
     public void onStart(){
         super.onStart();
 
@@ -130,7 +136,7 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
         if (mRoot)
             return getString(R.string.network_browsing);
         else
-            return Strings.getName(mMrl);
+            return mCurrentMedia != null ? mCurrentMedia.getTitle() : mMrl;
     }
 
     public boolean isRootDirectory(){
@@ -145,7 +151,7 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
         FragmentTransaction ft = getActivity().getSupportFragmentManager().beginTransaction();
         Fragment next = new NetworkFragment();
         Bundle args = new Bundle();
-        args.putString(KEY_MRL, media.getLocation());
+        args.putParcelable(KEY_MEDIA, media);
         next.setArguments(args);
         ft.replace(R.id.fragment_placeholder, next, media.getLocation());
         ft.addToBackStack(mMrl);
@@ -169,16 +175,16 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
     public void onBrowseEnd() {
         mAdapter.sortList();
         mHandler.sendEmptyMessage(NetworkFragmentHandler.MSG_HIDE_LOADING);
-        if (savedPosition > 0) {
-            mLayoutManager.scrollToPositionWithOffset(savedPosition, 0);
-            savedPosition = 0;
+        if (mSavedPosition > 0) {
+            mLayoutManager.scrollToPositionWithOffset(mSavedPosition, 0);
+            mSavedPosition = 0;
         }
         focusHelper(mAdapter.isEmpty());
     }
 
     @Override
     public void onRefresh() {
-        savedPosition = mLayoutManager.findFirstCompletelyVisibleItemPosition();
+        mSavedPosition = mLayoutManager.findFirstCompletelyVisibleItemPosition();
         refresh();
     }
 
@@ -241,11 +247,11 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
     public void refresh() {
         mAdapter.clear();
         if (mRoot){
-            ArrayList<String> favs = MediaDatabase.getInstance().getAllNetworkFav();
+            ArrayList<MediaWrapper> favs = MediaDatabase.getInstance().getAllNetworkFav();
             if (!favs.isEmpty()) {
                 mFavorites = favs.size();
-                for (String fav : favs) {
-                    mAdapter.addItem(new MediaWrapper(fav), false, true);
+                for (MediaWrapper fav : favs) {
+                    mAdapter.addItem(fav, false, true);
                     mAdapter.notifyDataSetChanged();
                 }
                 mAdapter.addItem("Network favorites", false, true);
@@ -259,7 +265,7 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
     }
 
     private void updateFavorites(){
-        ArrayList<String> favs = MediaDatabase.getInstance().getAllNetworkFav();
+        ArrayList<MediaWrapper> favs = MediaDatabase.getInstance().getAllNetworkFav();
         int newSize = favs.size(), totalSize = mAdapter.getItemCount();
 
         if (newSize == 0 && mFavorites == 0)
@@ -272,8 +278,8 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
         else {
             if (mFavorites == 0)
                 mAdapter.addItem("Network favorites", false, false); //add header if needed
-            for (String fav : favs)
-                mAdapter.addItem(new MediaWrapper(fav), false, false); //add new favorites
+            for (MediaWrapper fav : favs)
+                mAdapter.addItem(fav, false, false); //add new favorites
         }
         mFavorites = newSize; //update count
     }
@@ -283,7 +289,7 @@ public class NetworkFragment extends BrowserFragment implements IRefreshable, Me
         if (db.networkFavExists(mMrl))
             db.deleteNetworkFav(mMrl);
         else
-            db.addNetworkFavItem(mMrl);
+            db.addNetworkFavItem(mMrl, mCurrentMedia.getTitle());
         getActivity().supportInvalidateOptionsMenu();
     }
 
